@@ -52,7 +52,7 @@ class StockTestCase(unittest.TestCase):
         '''
         Test Move.internal_quantity.
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             category_id = self.category.create({
                 'name': 'Test Move.internal_quantity',
                 })
@@ -108,7 +108,8 @@ class StockTestCase(unittest.TestCase):
         '''
         Test products_by_location.
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             category_id = self.category.create({
                 'name': 'Test products_by_location',
                 })
@@ -301,7 +302,7 @@ class StockTestCase(unittest.TestCase):
         '''
         Test period.
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             category_id = self.category.create({
                 'name': 'Test period',
                 })
